---
name: Feature request
about: Request a new feature
labels: issue::type::enhancement
---

<!-- Remove this warning before posting the issue -->

⚠️ If you're not sure on the specifics of the feature or would like a broader discussion, please consider posting a proposal to [Discussions][Discussions] instead.

[Discussions]: https://github.com/robotology/gym-ignition/discussions

## Summary

Describe what this new feature is about and the context you would find it useful.

## Implementation suggestion

Provide a suggestion on how to implement this feature, which could help us to speed up the implementation.

## Additional context

Screenshots, videos, links, sketches, ...
